#
# spec file for package esbuild
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150700
# Go source packages are horribly broken on Leap (mismatching versions between libraries and compiler)
%bcond_with vendor
%else
%bcond_without vendor
%endif

#macros for Fedora
%global goipath  github.com/evanw/esbuild
%global tag   v%{version}
%global extractdir0 esbuild-%{version}
Name:           esbuild
Version:        0.25.3
Release:        1.1
Summary:        A JavaScript bundler written for speed
License:        MIT
Group:          Development/Languages/Other
URL:            https://esbuild.github.io
Source0:        https://github.com/evanw/esbuild/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Patch0:         remove-version-check.patch
BuildRequires:  util-linux
BuildRequires:  zstd
%if 0%{?fedora}
BuildRequires:  go-rpm-macros
BuildRequires:  golang
%else
BuildRequires:  golang-packaging
BuildRequires:  golang(API)
%endif

%if %{without vendor}
%if 0%{?fedora}
BuildRequires:  golang-ipath(golang.org/x/sys)
%else
BuildRequires:  golang-org-x-sys
%endif
%endif

%description
esbuild is a JavaScript bundler and minifier.

%{gopkg}

%prep
%if %{with vendor}
%autosetup -a1 -p1
%else
%autosetup -p1
%endif

%build
export CFLAGS="%{optflags} -fpie -fno-fat-lto-objects"
export CXXFLAGS="$CFLAGS"

export CGO_CFLAGS="$CFLAGS"
export CGO_CXXFLAGS="$CFLAGS"
export CGO_LDFLAGS="%{?build_ldflags}"

export GOFLAGS='-ldflags=-compressdwarf=false' #fix broken debuginfo bsc#1215402

%if 0%{?fedora}
%goprep -k -e
%else
%goprep %goipath
export GO111MODULE=off
%endif
%gobuild ./cmd/esbuild

%install
install -pvDm755 \
%if 0%{?fedora}
%name \
%else
%{_builddir}/go/bin/%{name} \
%endif
"%{buildroot}/%{_bindir}/%{name}"

%check
export CFLAGS="%{optflags} -fpie -fno-fat-lto-objects"
export CXXFLAGS="$CFLAGS"
export CGO_CFLAGS="$CFLAGS"
export CGO_CXXFLAGS="$CFLAGS"
export CGO_LDFLAGS="%{?build_ldflags}"
export GOFLAGS='-ldflags=-compressdwarf=false'
%if 0%{?fedora}
%gocheck
%else
export GO111MODULE=off
%gotest %goipath/...
%endif

%files
%license LICENSE.md
%doc CHANGELOG.md README.md
%{_bindir}/%{name}

%changelog
* Thu May  1 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.25.3:
  * Fix lowered async arrow functions before super() (#4141, #4142)
  * Fix memory leak with --watch=true (#4131, #4132)
  * More concise output for repeated legal comments (#4139)
  * Allow a custom host with the development server (#4110)
  * Add a limit to CSS nesting expansion (#4114)
  * Fix path resolution edge case (#4144)
  * Update Go from 1.23.7 to 1.23.8 (#4133, #4134)
* Wed Apr  2 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.25.2:
  * Support flags in regular expressions for the API (#4121)
  * Fix node-specific annotations for string literal export names (#4100)
  * Basic support for index source maps (#3439, #4109)
* Wed Mar 19 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.25.1:
  * Fix incorrect paths in inline source maps (#4070, #4075, #4105)
  * Fix invalid generated source maps (#4080, #4082, #4104, #4107)
  * Fix a regression with non-file source map paths (#4078)
  * Fix a crash with switch optimization (#4088)
  * Update Go from 1.23.5 to 1.23.7 (#4076, #4077)
* Sat Feb  8 2025 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.25.0:
  * Restrict access to esbuild's development server (GHSA-67mh-4wv8-2f99)
  * Delete output files when a build fails in watch mode (#3643)
  * Fix correctness issues with the CSS nesting transform (#3620,
    [#3877], #3933, #3997, #4005, #4037, #4038)
  * Fix some correctness issues with source maps (#1745, #3183, #3613, #3982)
  * Fix a minification bug with bitwise operators and bigints (#4065)
  * Fix esbuild incorrectly rejecting valid TypeScript edge case (#4027)
  * Transform BigInt values into constructor calls when unsupported (#4049)
* Sun Dec 22 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.24.2:
  * Fix regression with --define and import.meta (#4010, #4012, #4013)
- includes 0.24.1:
  * Allow es2024 as a target in tsconfig.json (#4004)
  * Allow automatic semicolon insertion after get/set
  * Allow quoted property names in --define and --pure (#4008)
  * Minify empty try/catch/finally blocks (#4003)
  * Include entryPoint metadata for the copy loader (#3985)
  * Source mappings may now contain null entries (#3310, #3878)
  * Avoid using the parent directory name for determinism (#3998)
  * Experimental support for esbuild on NetBSD (#3974)
- use zstd to compress vendor tarball
* Thu Nov  7 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.24.0:
  * Drop support for older platforms (#3902)
  * Fix class field decorators in TypeScript if useDefineForClassFields is false (#3913)
  * Avoid incorrect cycle warning with tsconfig.json multiple inheritance (#3898)
  * Handle Yarn Plug'n'Play stack overflow with tsconfig.json (#3915)
  * Work around more issues with Deno 1.31+ (#3917)
* Sat Jul  6 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.23.0:
  * Fix preserving collapsed JSX whitespace (#3818)
- includes 0.22.0:
  * Update await using behavior to match TypeScript
  * Allow es2024 as a target environment
  * Warn about onResolve plugins not setting a path (#3790)
  * Add a new Go API for running the CLI with plugins (#3539)
- change notes related to removed bundling experiment are omitted
* Mon Jun 10 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- Use correct optflags for generated C code
- Fix broken debuginfo (work around bsc#1215402)
- 15.6+ and Fedora: don't use vendor
- Run test suite in %%check
* Sun Jun  9 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.21.5:
  * Fix internal error with --supported:object-accessors=false (#3794)
  * Support ${configDir} in tsconfig.json files (#3782)
  * Support import attributes with glob-style imports (#3797)
  * Allow unknown import attributes to be used with the copy loader (#3792)
  * Fix Symbol.metadata on classes without a class decorator (#3781)
* Sun Jun  9 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.21.4:
  * Update support for import assertions and import attributes in
    node (#3778)
  * Fix for await transform when a label is present
  * Do additional constant folding after cross-module enum
    inlining (#3416, #3425)
  * Pass import attributes to on-resolve plugins (#3384, #3639, #3646)
  * Formatting support for the @position-try rule (#3773)
  * Always allow internal string import and export aliases (#3343)
- includes 0.21.3:
  * Implement the decorator metadata proposal (#3760)
  * Fix bundled decorators in derived classes (#3768)
  * Fix tsconfig.json files inside symlinked directories (#3767)
- includes 0.21.2:
  * Correct this in field and accessor decorators (#3761)
  * Allow es2023 as a target environment (#3762)
* Tue May  7 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.21.1:
  * Fix a regression with --keep-names (#3756)
- includes 0.21.0:
  * Implement the JavaScript decorators proposal (#104)
  * Optimize generated code for private methods
  * Fix an obscure bug with lowering class members with computed
    property keys
  * Fix some --keep-names edge cases
* Thu Mar 28 2024 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.20.0...0.20.2
  * Support TypeScript experimental decorators on `abstract` class fields #3684
  * constant folding for JavaScript inequality operators #3645
  * Fix cross-platform non-determinism with CSS color
    space transformations #3650
  * Fix a bug with the CSS nesting transform for older browsers
  * Work around issues with Deno 1.31+ #3682
  * Handle Yarn Plug'n'Play edge case with `tsconfig.json` #3698
  * Empty enums should behave like an object literal #3657
  * Improve dead code removal of `switch` statements #3659
  * JSON loader now preserves `__proto__` properties #3700
  * Other bug fixes
* Sun Feb 11 2024 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.19.1...0.20.0
  * compatibility with deno 1.40.0
  * preferred extension order changed
  - from: tsx,.ts,.jsx,.js,.css,.json
  - to: .jsx,.js,.css,.json,.tsx,.ts
  * see CHANGELOG.md for other changes
* Sat Aug 12 2023 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.18.12...0.19.1
  * see CHANGELOG.md for changes
* Thu Jul 13 2023 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.18.2...0.18.12
  * see CHANGELOG.md for changes
* Tue Jun 13 2023 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.17.18...0.18.2
  * see CHANGELOG.md for changes
* Fri May 12 2023 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.17.5...0.17.18
  * see CHANGELOG.md for changes
* Sun Jan 29 2023 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.15.11...0.17.5
  * see CHANGELOG.md for changes
- run spec-cleaner
* Fri Oct 14 2022 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.15.3...0.15.11
  * see CHANGELOG.md for changes
* Tue Aug 16 2022 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.14.36...0.15.3
  * see CHANGELOG.md for changes
* Wed Jul 13 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Use recommended flags
- Add Fedora build
- Add remove-version-check.patch to make the package more usable as a build require
* Mon Apr 18 2022 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.14.28...0.14.36
  * see CHANGELOG.md for changes
* Sun Mar 27 2022 Avindra Goolcharan <avindra@opensuse.org>
- roll 0.14.9...0.14.28
  * see CHANGELOG.md for changes
* Wed Dec 29 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.14.9:
  * see CHANGELOG.md for changes
* Thu Nov 25 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.13.15
  * see CHANGELOG.md for changes, additions or removals
* Sat Jun 19 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.12.9
  * feat: override "this" with --define (#1361)
  * fix: CSS minification with !important and duplicate declarations (#1372)
- includes 0.12.8
  * Plugins can now specify sideEffects: false (#1009)
  * Remove a warning about unsupported source map comments (#1358)
- includes 0.12.7
  * Quote object properties that are modern Unicode identifiers (#1349)
  * Ignore tsconfig.json files inside node_modules (#1355)
  * Fix missing --metafile when using --watch (#1357)
  * Add a hidden __esModule property to modules in ESM format (#1338)
- includes 0.12.6
  * Improve template literal lowering transformation conformance (#1327)
  * Only respect target in tsconfig.json when esbuild's target is not
    configured (#1332)
  * Fix the order of CSS imported from JS (#1342)
  * Fix an edge case with transforming export default class (#1346)
* Thu Jun  3 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.12.5
  * Add support for lowering tagged template literals to ES5
  * Change class field behavior to match TypeScript 4.3
  * Avoid generating character sequence </script>
  * Change the triple-slash reference comment for Deno
- includes 0.12.4
  * Reorder name preservation before TypeScript decorator evaluation
  * Potential fix for determinism issue (introduced 0.11.13)
  * Respect `target` in `tsconfig.json`
- includes 0.12.3
  * Ensure JSX element names start with a capital letter
  * Fix a single hyphen being treated as a CSS name
- includes 0.12.2
  * Various code generation and minification issues fixed
- includes 0.12.1
  * Ability to preserve JSX syntax
  * Update list of built-in node modules (added wasi and _http_common)
- includes 0.12.0
  * Fix bundled CSS import order
  * Fix bundled CSS when using JS code splitting
  * Change "define" to have higher priority than "inject"
  * Support for "NO_COLOR" environment variable
* Sun May 16 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.23
  * Add a shim function for unbundled uses of require
  * Fix incorrect caching of internal helper function library
  * Minor performance improvements
- includes 0.11.22
  * Add support for the "import assertions" proposal
  * Forbid the token sequence `for ( async of` when not followed by `=>`
  * Restrict super property access to inside of methods
- includes 0.11.21
  * TypeScript override for parameter properties
  * Fix duplicate export errors due to TypeScript import-equals statements
  * Add support for type-only TypeScript import-equals statements
- includes 0.11.20
  * Omit warning about duplicate JSON keys from inside node_modules
  * Add CSS minification for box-shadow values
  * Fix object spread transform for non-spread getters
  * Prevent private class members from being added more than once
* Thu May  6 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.19
  * Allow esbuild to be restarted in Deno
  * Fix code splitting edge case
  * Fix code generation with declare class fields
  * Annotate module wrapper functions in debug builds
  * Add CSS minification for more cases
  * Preserve quotes around properties when minification is disabled
- includes 0.11.18
  * Fix an incorrect warning about top-level this
- includes 0.11.17
  * Fix building with a large stdin string with Deno
  * Add a warning about replacing this with undefined in ESM code
  * Allow a string literal as a JSX fragment
  * Fix metafile in onEnd with watch mode enabled
- includes 0.11.16
  * Fix TypeScript enum edge case
  * Parse the @-moz-document CSS rule
  * Fix syntax error in TypeScript-specific speculative arrow function parsing
  * Further changes to the behavior of the browser field
  * Avoid placing a super() call inside a return statement
  * Fix a bug with onEnd and watch mode
  * Fix an edge case with minified export names and code splitting
  * Provide a friendly error message when you forget async
* Tue Apr 27 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.15
  * Provide options for how to handle legal comments
  * Add onStart and onEnd callbacks to the plugin API
- includes 0.11.14
  * Implement arbitrary module namespace identifiers
  * Implement more accurate sideEffects behavior from Webpack
- includes 0.11.13
  * Implement ergonomic brand checks for private fields
  * Add the --allow-overwrite flag
  * Minify property accesses on object literals
  * Improve arrow function parsing edge cases
- includes 0.11.12
  * Fix a bug where -0 and 0 were collapsed to the same value
  * Match the TypeScript compiler's output in a strange edge case
  * Separate the debug log level into debug and verbose
* Thu Apr 15 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.11
  * Initial support for Deno
  * Remove warnings about non-bundled use of require and import
* Wed Apr 14 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.10
  * Provide more information about exports map import failures if possible
- includes 0.11.9
  * Fix escaping of non-BMP characters in property names
  * Be maximally liberal in the interpretation of the browser field
- includes 0.11.8
  * Fix hash calculation for code splitting and dynamic imports
  * Refactor the internal module graph representation
- includes 0.11.7
  * Fix incorrect chunk reference with code splitting, css, and dynamic imports
  * Split apart tree shaking and code splitting
  * Make "this" work in static class fields in TypeScript files
  * Various fixes for private class members
* Wed Apr  7 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.6
  * Fix an incorrect minification transformation
  * Change how NODE_PATH works to match node
  * Provide a better error message for incorrectly-quoted JSX attributes
* Sun Apr  4 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.5
  * Add support for the override keyword in TypeScript 4.3
  * Allow async plugin setup functions
  * Add some optimizations around hashing
  * Disable tree shaking annotations when code splitting is active
- includes 0.11.4
  * Avoid name collisions with TypeScript helper functions
  * Fix a chunk hashing issue
- includes 0.11.3
  * Auto-define process.env.NODE_ENV when platform is set to browser
  * Retain side-effect free intermediate re-exporting files
  * Add a very verbose debug log level
* Thu Apr  1 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.11.2
  * Fix missing symbol dependency for wrapped ESM files
  * Fix an edge case with entry points and top-level await
- includes 0.11.1
  * Fix a missing space before internal import() when minifying
  * Fix code generation for unused imported files without side effects
  * Allow top-level await in supported environments
  * Convert import() to require() if import() is not supported
- includes 0.11.0
  * Change how require() and import() of ESM works
  * Dynamic imports now use chunk names instead of entry names
  * Allow custom output paths for individual entry points
  * Derive entry point output paths from the original input path
  * Use the file namespace for file entry points
  * Warn about mutation of private methods
  * Fix some obscure TypeScript type parsing edge cases
- includes 0.10.2
  * Fix CSS crash introduced in the previous release
  * Fix private fields inside destructuring assignment
  * Fix an issue with direct eval and top-level symbols
* Fri Mar 26 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.10.1
  * Remove the file splitting optimization
  * Add a formatMessages API
  * Expose metafile to onRebuild in watch mode
- includes 0.10.0
  * feature: Initial support for bundling with top-level await
  * feature: Add the ability to set sourceRoot in source maps
  * feature: Allow plugins to return custom file watcher paths
  * No longer support module or exports in an ESM file
  * No longer change import() to require()
  * Run-time export * as statements no longer convert the file to CommonJS
  * Change whether certain files are interpreted as ESM or CommonJS
- includes 0.9.7
  * Fix incorrect MIME types on Windows
  * Using a top-level return inside an ECMAScript module is now forbidden
* Sun Mar 21 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.9.6
  * Expose build options to plugins
  * Fix an edge case with the object spread transform
  * Fix a TypeScript parsing edge case with arrow function return types
  * Enable faster synchronous transforms under a flag
  * Update how optional chains are compiled to match new V8 versions
- includes 0.9.5
  * Fix parsing of the [dir] placeholder
- includes 0.9.4
  * Enable hashes in entry point file paths
  * Fix importing a path containing a ? character on Windows
  * Parse and ignore the deprecated @-ms-viewport CSS rule
  * Avoid mutating the binary executable file in place
  * Avoid warning about potential issues with sideEffects in packages
- includes 0.9.3
  * Fix path resolution with the exports field for scoped packages
  * Improved error message in exports failure case
  * Mention glob syntax in entry point error messages
  * Raise certain VM versions in the JavaScript feature
    compatibility table
  * Mention the configured target environment in error messages
  * Fix an issue with Unicode and source maps
* Sun Mar 14 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.9.2:
  * Fix export name annotations in CommonJS output for node
- includes 0.9.1:
  * Always lower object spread and rest when targeting V8
  * Fix object rest return value
  * Basic support for CSS page margin rules
  * Add export name annotations to CommonJS output for node
  * Fix bundling when parent directory is inaccessible
  * Avoid allocations in JavaScript API stdout processing
  * Support conditional @import syntax when not bundling
* Wed Mar 10 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.9.0:
  * Add support for node's exports field in package.json files
  * Banner and footer options explicitly set js vs. css
  * The extensions .mjs and .cjs are no longer implicit
  * Remove the --summary flag and instead just always print a summary
  * Rename --error-limit= to --log-limit=
  * Remove the metafile from outputFiles
  * Remove the deprecated --avoid-tdz optioon
  * Remove the esbuild.startService() API
  * Remove Spinner options from Go API
* Fri Mar  5 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.56
  * Fix a discrepancy with esbuild's tsconfig.json implementation
  * Work around the Jest testing framework breaking node's Buffer API
  * Better handling of implicit main fields in package.json
- includes 0.8.55
  * Align more closely with node's default import behavior for CommonJS
  * Fix bug when ESM file has empty exports and is converted to CommonJS
  * Avoid introducing this for imported function calls
* Tue Mar  2 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.54
  * Fix ordering issue with private class methods
  * Fix --keep-names for private class members
  * Fix cross-chunk import paths
  * Remove the guarantee that direct eval can access imported symbols
- includes 0.8.53
  * Support chunk and asset file name templates
  * Handle this in class static field initializers
  * Do not warn about dynamic imports when .catch() is detected
  * CSS namespaces are no longer supported
- includes 0.8.52
  * Fix a concurrent map write with the --inject: feature
  * Provide kind to onResolve plugins
* Wed Feb 24 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.51
  * The stderr log format now contains line numbers after file names
  * Allow --define with import.meta
  * Fix a race condition with multiple injected files
  * Change --serve behavior to serve on all interfaces
  * Change the import resolution rules of absolute paths
  * Output files in metafile now have entryPoint
- includes 0.8.50
  * Using direct eval now pulls in module and exports
  * Always remove all "use asm" directives
  * Fix a variable hoisting edge case
  * Remove empty CSS rules when minifying
* Fri Feb 19 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.49
  * Work around a problem with pnpm and NODE_PATH
  * Add more names to the global no-side-effect list
  * Fix a TypeScript parser regression
  * Add the Go-specific cli.ParseServeOptions() API
- includes 0.8.48
  * Fix various parsing edge cases
  * Remove local web server feature from the WebAssembly package
- includes 0.8.47
  * Omit warning about require.someProperty when targeting CommonJS
  * Support ignored URL parameters at the end of import paths
  * Prevent paths starting with / from being used as relative paths on Windows
  * Warn when importing a path with the wrong case
* Sun Feb 14 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.46
  * Fix minification of .0 in CSS
  * Support range requests in local HTTP server
- includes 0.8.45
  * Add the --servedir= flag
  * Handle absolute paths in tsconfig.json
  * Change the watch mode output format
- includes 0.8.44
  * Create logo for esbuild
  * Add support for node's --preserve-symlinks flag
  * Ignore a leading byte order mark (BOM) in CSS files
  * Add message notes to the API
  * Add origin information to errors from plugins
  * Fix a regression with the synchronous JavaScript API
  * Remove absolute paths for disabled files from source maps
- includes 0.8.43
  * Support the XDG_CACHE_HOME environment variable
  * Further improve constant folding of branches
  * Fix an edge case with CSS variable syntax
  * Add support for recursive symlinks during path resolution
  * Fix subtle circular dependency issue
  * Add support for the NODE_PATH environment variable
- includes 0.8.42
  * Fix crash with block-level function declaration and --keep-names
  * Disallow additional features in strict mode
  * Basic support for watch mode with plugins
  * Make JavaScript API error format more consistent
* Thu Feb  4 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.41
  * Special-case certain syntax with --format=esm
  * Basic "use strict" tracking
  * Fix a minifier bug when transforming "with" clauses
  * Transform block-level function declarations
- includes 0.8.40
  * Fix TypeScript parameter decorators on class constructors
  * Resolve browser entries in package.json with no file extension
- includes 0.8.39
  * Add an API option for a per-build working directory
  * Fix stray esbuild process after node exits
- includes 0.8.38
  * --watch mode added
  * Add pluginData to pass data between plugins
- includes 0.8.37
  * Improve ambiguous import handling
  * Reuse automatically-generated temporary *.node files
  * Fix the serve API with outfile
* Tue Jan 26 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.36
  * hide N-API native node extensions from Yarn 2
- includes 0.8.35
  * Fix a commonly-missed corner case with await inside **
  * Allow namespaced names in JSX syntax
  * Fix worker: false in esbuild's browser-based JavaScript API
  * Add a hack for faster command-line execution for the WebAssembly
    module in certain cases
  * Fix non-absolute paths with the esbuild-wasm package in the browser
- includes 0.8.34
  * Fix a parser bug about suffix expressions after an arrow function body
  * Add new neutral platform to help text
* Wed Jan 20 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.33
  * Fix esbuild potentially exiting early during incremental rebuilds
  * Fix using the new sourcesContent option with the transform API
  * Insert the object spread shim in constructor methods after the super() call
  * Add the --platform=neutral API option
  * Provide minified and non-minified versions of in-browser API library
- strip binary
* Thu Jan 14 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.32
  * Calling stop() on the JavaScript API is now optional
  * Fix bug in metafile path generation
  * Add kind to import JavaScript and CSS paths in metafile JSON
  * Add support for TypeScript 4.2 syntax (abstract construct signatures)
  * Add detail to errors and warnings
  * Disable code warnings inside node_modules directories even with plugins
  * Remove the warning about self-assignment
  * Disable constant folding for the ?: operator when not minifying
* Thu Jan  7 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.31
  * Fix minification issue from previous release
  * Add the option --sourcemap=both
  * Tree-shake unused code with --format=iife
* Wed Jan  6 2021 Avindra Goolcharan <avindra@opensuse.org>
- update to 0.8.30
  * Fix @jsx and @jsxFrag comments without trailing spaces
  * Minification improvements
  * Fix issues with nested source maps
* Mon Jan  4 2021 Avindra Goolcharan <avindra@opensuse.org>
- initial package at 0.8.29
